@@ -3,7 +3,7 @@ import types
 from simplesettings.exceptions import SettingsException
 from simplesettings.parsers import JsonSettingsParser, YamlSettingsParser, IniSettingsParser
 from simplesettings.logger import logger
-from simplesettings.vars import SimpleVars
+from simplesettings.vars import SettingVars
 
 
 OBJECT_ROUTER = {
@@ -30,28 +30,31 @@ class Settings(object):
 
         Input:
 
-         Filename   - The name of the settings file
-         Parser     - The parser type, for now either json or yaml
+        Filename           - The name of the settings file
+
+        Parser             - The parser type, for now either json or yaml
+
+        Additional fields  - A dict with additional settings that should be included in the object
+
+        Mandatory fields   - A list with keys that should be present in the settings or additional fields.
+                             If not present, a SettingsException is raised.
 
          Output:
 
          A settings object with both data as a dictionary as well as split up into strings to prevent deep nesting.
 
     """
-    mandatory_fields = []
-
-    def __init__(self, filename, parser, mandatory_fields=()):
+    def __init__(self, filename, parser, additional_fields={}, mandatory_fields=[]):
         try:
             file_parser = OBJECT_ROUTER[parser]
             self.data = Wrap()
             self.data.parser = file_parser(filename=filename)
             self.data.dict = self.data.parser.parse()
-            self.vars = SimpleVars(input_dict=self.data.dict)
-        except (TypeError, KeyError):
+            self.data.dict.update(additional_fields)
+            self.vars = SettingVars(input_dict=self.data.dict)
+        except (TypeError, KeyError, ValueError):
             raise SettingsException('File parser not found! Please use "ini, "json" or "yaml"')
 
-        if self.mandatory_fields:
-            mandatory_fields = self.mandatory_fields
         self.sanity(fields=mandatory_fields)
 
         for key in self.data.dict:
